FinishButtonStyle class

Constructors

FinishButtonStyle({ShapeBorder? shape = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(5.0))), double? elevation = 0, double? focusElevation, double? hoverElevation, double? highlightElevation, double? disabledElevation, Color? foregroundColor, Color? backgroundColor, Color? focusColor, Color? hoverColor, Color? splashColor})
const

Properties

backgroundColor → Color?
final
disabledElevation → double?
final
elevation → double?
final
focusColor → Color?
final
focusElevation → double?
final
foregroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
highlightElevation → double?
final
hoverColor → Color?
final
hoverElevation → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
final
splashColor → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited